Summarize an APA/FACETS table object
Usage
# S3 method for class 'apa_table'
summary(object, digits = 3, top_n = 8, ...)Arguments
- object
Output from
apa_table().- digits
Number of digits used for numeric summaries.
- top_n
Maximum numeric columns shown in
numeric_profile.- ...
Reserved for generic compatibility.
Interpreting output
overview: table size/composition and missingness.numeric_profile: quick distribution summary of numeric columns.caption/note: text metadata readiness.
Typical workflow
Build table with
apa_table().Run
summary(tbl)and inspectoverview.Use
plot.apa_table()for quick numeric checks if needed.
Examples
# \donttest{
toy <- load_mfrmr_data("example_core")
fit <- fit_mfrm(toy, "Person", c("Rater", "Criterion"), "Score", method = "JML", maxit = 300)
tbl <- apa_table(fit, which = "summary")
summary(tbl)
#> APA Table Summary
#> Branch Style Which Rows Columns NumericColumns MissingValues
#> apa apa summary 1 88 40 14
#>
#> Caption
#> - Table 1
#> Facet Summary (Measures, Precision, Fit, Reliability)
#>
#> Note
#> - Measures are reported in logits; higher person values indicate higher ability, and higher non-person facet values indicate greater severity/difficulty (all non-person facets used the default negative orientation in this fit). Model S.E. = exploratory standard error; Real S.E. = fit-adjusted exploratory standard error; MnSq = mean-square fit. Report eligible interval limits (95%, Normal approximation) alongside measures; intervals that do not meet the reporting requirements remain descriptive. Model = RSM; estimation = JML; N = 768 observations from 48 persons on a 4-category scale (1-4).
#>
#> Numeric profile
#> Column N Mean SD Min Max
#> AIC 0 NA NA NA NA
#> BIC 0 NA NA NA NA
#> Categories 1 4.0 NA 4.0 4.0
#> ConvergenceCode 1 0.0 NA 0.0 0.0
#> Deviance 1 1641.9 NA 1641.9 1641.9
#> EMIterations 0 NA NA NA NA
#> EMRelativeChange 0 NA NA NA NA
#> EffectiveReltol 1 0.0 NA 0.0 0.0
# }