as_flextable.apa_table: Convert an 'apa_table' to a 'flextable'

View source: R/api-reports.R

as_flextable.apa_tableR Documentation

Convert an apa_table to a flextable

Description

Produces a Word / PowerPoint-friendly flextable with the caption and note wired in. Requires flextable (in Suggests).

Usage

## S3 method for class 'apa_table'
as_flextable(x, ...)

Arguments

x

An apa_table object from apa_table().

...

Additional arguments reserved for future use.

Value

A flextable object, or a message when flextable is unavailable.

See Also

as_kable.apa_table(), apa_table().


mfrmr documentation built on June 13, 2026, 1:07 a.m.