Skip to contents

Summarize a facet-quality dashboard

Usage

# S3 method for class 'mfrm_facet_dashboard'
summary(object, digits = 3, top_n = 10, ...)

Arguments

object

Output from facet_quality_dashboard().

digits

Number of digits for printed numeric values.

top_n

Number of flagged levels to preview.

...

Reserved for generic compatibility.

Value

An object of class summary.mfrm_facet_dashboard.

Examples

# \donttest{
toy <- load_mfrmr_data("example_core")
fit <- fit_mfrm(toy, "Person", c("Rater", "Criterion"), "Score", method = "JML", maxit = 30)
#> Warning: Optimization convergence review did not produce an inference-ready numerical solution (code = 1, status = iteration_limit). Optimizer reached the iteration limit before the terminal gradient became small enough for review-only acceptance. Inspect the model specification, data support, and starting values. Do not interpret estimates until the review is resolved.
diag <- diagnose_mfrm(fit, residual_pca = "none")
summary(facet_quality_dashboard(fit, diagnostics = diag))
#> mfrmr Facet Quality Dashboard Summary
#> 
#> Overview
#>  Facet FacetSource Levels FlaggedLevels BiasSourceBundles
#>  Rater    inferred      4             2                 0
#> 
#> Summary
#>  Facet Levels MeanEstimate    SD MinEstimate MaxEstimate MeanInfit MeanOutfit
#>  Rater      4            0 0.313      -0.329       0.333     0.994      1.019
#>  SeverityFlagged MisfitFlagged CentralTendencyFlagged BiasFlagged AnyFlagged
#>                0             0                      2           0          2
#>  BiasRows
#>         0
#> 
#> Flagged levels
#>  Facet Level Estimate N.x    SE ModelSE RealSE                     SE_Method
#>  Rater   R01   -0.196 192 0.097   0.097  0.100 Observation-table information
#>  Rater   R03    0.191 192 0.097   0.097  0.097 Observation-table information
#>  Converged InferenceReady ConvergenceSeverity PrecisionTier
#>      FALSE          FALSE                fail   exploratory
#>      FALSE          FALSE                fail   exploratory
#>  SupportsFormalInference          SEUse
#>                    FALSE screening_only
#>                    FALSE screening_only
#>                                                CIBasis          CIUse N.y Infit
#>  Normal interval from exploratory observation-table SE screening_only 192 1.051
#>  Normal interval from exploratory observation-table SE screening_only 192 0.964
#>  Outfit InfitZSTD OutfitZSTD DF_Infit DF_Outfit N.x.x ObservedAverage
#>   1.045     0.408      0.464  105.624       192   192           2.609
#>   0.970    -0.217     -0.263  105.751       192   192           2.396
#>  ExpectedAverage Bias MeanResidual MeanStdResidual MeanAbsStdResidual   ChiSq
#>            2.609    0            0          -0.009              0.841 200.557
#>            2.396    0            0           0.001              0.812 186.231
#>  ChiDf  ChiP SE_Residual t_Residual p_Residual SE_StdResidual t_StdResidual
#>    191 0.303       0.054          0          1          0.072        -0.122
#>    191 0.584       0.054          0          1          0.072         0.014
#>  p_StdResidual  DF PTMEA N.y.y CI_Lower CI_Upper CI_Level            CI_Method
#>          0.903 191 0.623   192   -0.386   -0.005     0.95 Normal approximation
#>          0.989 191 0.658   192    0.000    0.382     0.95 Normal approximation
#>  CIEligible                              CILabel   N AbsEstimate SeverityFlag
#>       FALSE Approximate interval; screening only 192       0.196        FALSE
#>       FALSE Approximate interval; screening only 192       0.191        FALSE
#>  MisfitFlag CentralTendencyFlag BiasCount BiasSources BiasFlag FlagCount
#>       FALSE                TRUE         0           0    FALSE         1
#>       FALSE                TRUE         0           0    FALSE         1
#>  AnyFlag FlagLabel .AbsEstimate
#>     TRUE   central        0.196
#>     TRUE   central        0.191
#> 
#> Settings
#>               Setting    Value
#>                 facet    Rater
#>          facet_source inferred
#>         severity_warn        1
#>           misfit_warn      1.5
#>  central_tendency_max     0.25
#>       bias_count_warn        1
#>       bias_abs_t_warn        2
#>    bias_abs_size_warn      0.5
#>            bias_p_max     0.05
#>   bias_source_bundles        0
#> 
#> Notes
#>  - Dashboard constructed successfully.
# }